# Majority Judgment

## Common language

The Majority Judgment asks us to answer to a specific, operationally pertinent,
question about several choices, by judging each choice in an absolute way
(i.e. such that the removal or addition of choices
does not change our evaluation of the other choices)
by giving them a grade (or level) on a common scale.

This common scale contains as many grades as our supposed common expertise
is able to distinguish, in order to faithfully represent
the properties of the attribute it tries to measure.
Hence, a common scale should be crafted for each different attribute.
The inter-subjective meaning of each grade
being reinforced by the practice of judgments.

### Examples

Examples of common scales could be:
- [“No”, “No, but”, “Yes, but”, “Yes”] for adhesion,
- [“None”, “Not Enough”, “Enough”, “Much”, “Too Much”] for quantity,
- [“To Do”, “Prioritized”, “Blocking”, “Urgent”, “Too Urgent”] for priority,
- [“Useless”, “Interesting”, “Useful”, “Indispensable”, “Enslaving”] for utility,
- [“To Reject”, “Insufficient”, “Acceptable”, “Good”, “Very Good”, “Too Good”] for quality.

## Judging one choice

For each choice taken separately,
each grade of the scale is associated to the number
of individual judgments which have given this grade to this choice.
(eg. for 5 judges: [“Insufficient”, “Acceptable”, “Acceptable”, “Good”, “Good”])
This forms a dilated scale where each grade is expanded (resp. shrunk)
when more (resp. less) supported than the others.
Like this, the only grade which is defended by an absolute majority
begining from one side of the scale,
without being rejected by an absolute majority
beginning from the other side of the scale,
is the one which spans over the middlemost
of this dilated scale (here: “Acceptable”).
This is the most consensual majority grade for this choice.

If the number of individual judgments is small and even
(eg. for 6 judges: [“Insufficient”, “Acceptable”, “Acceptable”, “Good”, “Good”, “Good”]),
there is however a probability that two different grades
border the middlemost of this dilated scale (here: [“Acceptable”, “Good”]).
But only the lower grade (here: “Acceptable”) rewards consensus,
and thus is considered to be the most consensual.
Indeed, if any other choice obtains less scattered judgments
(eg. [“Acceptable”, “Acceptable”, “Acceptable”, “Acceptable”, “Good”, “Good”])
all enclosed into these two grades,
it will obtain a most consensual majoritary grade
greater or egal to the one of this choice (here: “Acceptable”).
Which would not necessarily be the case with the greater grade (here: “Good”).

## Ranking many choices

To sort many choices means being able to compare them two-by-two,
which is done according to their most consensual majority grade.
In case of equality, the minimum individual judgments of this grade
are removed from both dilated scales so that one of them has no longer any,
then the comparison goes on with the new most consensual majority grades.
Like this, either a choice is judged higher than the other,
by the geatest number of judgments which differenciate them according
to a most consensual majoritary grade,
or both choices precisely have the same distribution of individual judgments.

One can see that the farest an individual judgment is
from the most consensual majoritary grade,
the less impact it has on the result.
This rewards honest individual judgments,
by ignoring as near as may be the most cranky or strategic judgements.

## Properties

The Majority Judgment is:

- allowing anonymity:
  interchanging the names of judges does not change the outcome:
  all judges are given an equal power.

- neutral:
  interchanging the names of choices does not change the outcome:
  all choices are treated equally.

- complete:
  every choice is either superior or inferior
  to any other choice, or both when equal.
  Hence the Majority Judgement is not subject
  to Condorcet's paradox.

- monotone:
  if a choice is superior or egal to another one,
  and a judge increases its grade for it,
  it becomes strictly superior.

- transitive:
  if a first choice is superior to a second one,
  and this second one is superior to a third,
  then the first is superior to the third).

- coherent:
  it is independent of irrelevant alternatives as formulated by Nash-Chernoff:
  removal or addition of choices does not change
  the judges’ evaluations of the other choices.
  Hence the Majority Judgement is not subject
  to Arrow's paradox.

- strategy-proof-in-grading:
  judging a choice higher or lower
  than our intimate judgement has the opposite impact
  on its most consensual majority grade.

- partially strategy-proof-in-ranking:
  increasing (resp. decreasing) the rank of a choice with respect to another choice,
  can not decrease (resp. increase) the rank of this other choice.

- not Condorcet-consistent:
  not guarantying the selection of a choice
  which is preferred by a majority against every of the others separately.
  
  Except when the electorate is “polarized”:
  when the higher (resp. the lower) a judge evaluates one choice the lower (resp. the higher)
  she/he evaluates the other, so there can be no consensus;
  hence when judges are most tempted to manipulate.
  
  This property is judged undesirable, by Michel Balinski and Rida Laraki,
  as they prove how easily the Majority Rule can go wrong when voting
  on but two candidates, let alone more.

- not excluding the no-show paradox:
  it may be better for a judge not to judge
  than to express her/his opinion sincerely because her/his vote
  can tip the scales against his favorite choice.
  
  This property is judged insignificant, by Michel Balinski and Rida Laraki,
  when compared with the serious problems of methods of election,
  the Arrow and Condorcet paradoxes and strategic manipulation.
  Moreover, the only methods based on measuring that exclude
  the no-show paradox are point-summing methods,
  which, amongst other drawbacks, are highly manipulable.

## Resources
- [Majority Judgment: Measuring, Ranking, and Electing](http://libgen.io/book/index.php?md5=BF67AA4298C1CE7633187546AA53E01D) (en)
- [Majority Judgment vs. Majority Rule](http://www.lamsade.dauphine.fr/sites/default/IMG/pdf/cahier_377.pdf) (en)
- [Judge : Don't Vote!](https://1007421605497013616-a-1802744773732722657-s-sites.googlegroups.com/site/ridalaraki/xfiles/BalinskiLarakiJudgeDontVotecahierderecherche2010-27.pdf) (en)
- [Jugement majoritaire versus vote majoritaire (via les présidentielles 2011-2012)](https://www.cairn.info/revue-francaise-d-economie-2012-4-page-11.htm) (fr)
- [Majority Judgment vs. Majority Rule](http://www.lamsade.dauphine.fr/sites/default/IMG/pdf/cahier_377.pdf) (en)
- [What Should “Majority Decision” Mean?](https://1984f707-a-62cb3a1a-s-sites.googlegroups.com/site/ridalaraki/xfiles/BalinskiLaraki%28ElsterBook%292014.pdf?attachauth=ANoY7cqCY4F_kQdtBc2d9EtUDNNPqtuoOYj98ThvPFukdXBkzogggu_WcKe2SryAQ9tq0P1HaGHHhD6sOdBNQ-ttaQ9XJUjVPHVCsMp4PDuX_DlvMv8MYqG6SGy_m39Q9tztOWezturc9q50RMHs0CKEGqiBqnRlyP4BFo5i4PqHDT5nD2v0HTsINWs6PooIz-bZpeuUXST1A30ojKDQ_b5xsK50RFMkJT7LG-p441cGlUOQWIGYikd2XglJdBJr0N5YuL80ZePd&attredirects=0) (en)
- [Condorcet-Consistent and Approximately Strategyproof Tournament Rules](https://arxiv.org/pdf/1605.09733.pdf) (en)
